#
# spec file for package python-statsmodels
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-statsmodels
Version:        0.10.2
Release:        bp153.1.20
Summary:        A Python module that allows users to explore data
License:        BSD-3-Clause
Group:          Development/Libraries/Python
URL:            http://statsmodels.sourceforge.net/
Source:         https://files.pythonhosted.org/packages/source/s/statsmodels/statsmodels-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module matplotlib >= 1.0.0}
BuildRequires:  %{python_module numpy-devel >= 1.7.0}
BuildRequires:  %{python_module pandas >= 0.7.1}
BuildRequires:  %{python_module patsy >= 0.3.0}
BuildRequires:  %{python_module scipy >= 0.9.0}
BuildRequires:  %{python_module setuptools >= 0.6}
BuildRequires:  fdupes
BuildRequires:  gcc-fortran
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.7.0
Requires:       python-pandas >= 0.7.1
Requires:       python-patsy >= 0.3.0
Requires:       python-scipy >= 0.9.0
Recommends:     python-matplotlib >= 1.0.0
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Statsmodels is a Python module that allows users to explore data,
estimate statistical models, and perform statistical tests.
An extensive list of descriptive statistics, statistical tests,
plotting functions, and result statistics are available for different
types of data and each estimator. Researchers across fields may find
that statsmodels fully meets their needs for statistical computing
and data analysis in Python.

%prep
%setup -q -n statsmodels-%{version}
rm -rf statsmodels/.pytest_cache
find . -type f -name "*.py" -exec sed -i 's/\r$//' {} \;
find statsmodels -type f -name "*.py" -exec sed -i "/#! \/usr\/bin\/env python/d" {} \;
find statsmodels -type f -name "*.py" -exec sed -i "/#!\/usr\/bin\/env python/d" {} \;
find statsmodels -type f -name "*.py" -exec sed -i "/#! \/usr\/bin\/env python3/d" {} \;
find statsmodels -type f -name "*.py" -exec sed -i "/#!\/usr\/bin\/env python3/d" {} \;
find . -type f -name "*.ipynb" -exec sed -i 's/\r$//' {} \;
sed -i 's/\r$//' COPYRIGHTS.txt
sed -i 's/\r$//' LICENSE.txt
sed -i 's/\r$//' README.rst
sed -i 's/\r$//' README_l1.txt
sed -i 's/\r$//' statsmodels/tsa/statespace/tests/results/results_wpi1_ar3_stata.csv
sed -i 's/\r$//' statsmodels/tsa/regime_switching/tests/results/mar_filardo.csv
sed -i 's/\r$//' statsmodels/tsa/statespace/tests/results/results_wpi1_ar3_stata.csv
sed -i 's/\r$//' statsmodels/tsa/regime_switching/tests/results/mar_filardo.csv
chmod a-x COPYRIGHTS.txt
chmod a-x LICENSE.txt
chmod a-x README.rst
chmod a-x README_l1.txt

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

# Remove unwanted setup files
%python_expand find %{buildroot}%{$python_sitearch} -name 'setup.py*' -exec rm {} \;
%python_expand find %{buildroot}%{$python_sitearch} -type f -exec chmod a-x {} \;
rm -f %{buildroot}%{_prefix}/LICENSE.txt
rm -f %{buildroot}%{_prefix}/setup.cfg

%ifnarch ppc64le
%check
export PYTHONDONTWRITEBYTECODE=1 # do not write unreproducible .pyc files
mv statsmodels statsmodels_temp
rm -rf build _build.*
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
pytest-%{$python_bin_suffix} -p no:cacheprovider %{buildroot}%{$python_sitearch}/statsmodels/
}
mv statsmodels_temp statsmodels
%endif

%files %{python_files}
%doc README.rst README_l1.txt
%doc examples/
%license COPYRIGHTS.txt LICENSE.txt
%{python_sitearch}/statsmodels/
%{python_sitearch}/statsmodels-%{version}-py*.egg-info

%changelog
* Sun Nov 24 2019 Arun Persaud <arun@gmx.de>
- update to version 0.10.2:
  * This is a bug release and adds compatibility with Python 3.8.
* Mon Jul 29 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Stop packaging unreproducible .pyc files
* Mon Jul 22 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.10.1
  * Bugfix release
- Update to 0.10.0
  Highlights:
  * Generalized Additive Models
  * Conditional Models
  * Dimension Reduction Methods
  * Regression using Quadratic Inference Functions (QIF)
  * Gaussian Process Regression
  * Burg's Method
  * Time series Tools
  * Knockoff effect estimation has been added for a many models
  * Influence functions are available for GLM and generic MLE models:
- Remove upstream-included pandas_to_datetime.patch
* Tue Aug 14 2018 toddrme2178@gmail.com
- Update to 0.9.0
  Highlights:
  * statespace refactoring, Markov Switching Kim smoother
  * Bayesian mixed GLM
  * Gaussian Imputation
  * new multivariate methods: factor analysis, MANOVA, repeated measures within ANOVA
  * GLM var_weights in addition to freq_weights
  * Holt-Winters and Exponential Smoothing
- Add pandas_to_datetime.patch
  to_datetime has been moved in pandas.
  Should be in next release
  From: https://github.com/statsmodels/statsmodels/pull/4640
* Thu May  4 2017 toddrme2178@gmail.com
- Update to 0.8.0 final
  * The main features of this release are several new time series models based
    on the statespace framework, multiple imputation using MICE as well as many
    other enhancements. The codebase also has been updated to be compatible with
    recent numpy and pandas releases.
  * For a full ist see: http://www.statsmodels.org/stable/release/version0.8.html
- Implement single-spec version
* Fri Oct 28 2016 toddrme2178@gmail.com
- Fix download URL.
* Fri Oct 28 2016 toddrme2178@gmail.com
- Update to Release 0.8.0rc1
  + Release summary
    The main features of this release are several new time series models based
    on the statespace framework, multiple imputation using MICE as well as many
    other enhancements. The codebase also has been updated to be compatible with
    recent numpy and pandas releases.
  + Statespace Models
  * Building on the statespace framework and models added in 0.7, this release
    includes additional models that build on it.
  + Kalman Smoother
  * The Kalman smoother (introduced in #2434) allows making inference on the
    unobserved state vector at each point in time using data from the entire
    sample. In addition to this improved inference, the Kalman smoother is required
    for future improvements such as simulation smoothing and the expectation
    maximization (EM) algorithm.
  * As a result of this improvement, all state space models now inherit a `smooth`
    method for producing results with smoothed state estimates. In addition, the
    `fit` method will return results with smoothed estimates at the maximum
    likelihood estimates.
  + Postestimation
  * Improved post-estimation output is now available to all state space models
    (introduced in #2566). This includes the new methods `get_prediction` and
    `get_forecast`, providing standard errors and confidence intervals as well
    as point estimates, `simulate`, providing simulation of time series following
    the given state space process, and `impulse_responses`, allowing computation
    of impulse responses due to innovations to the state vector.
  + Diagnostics
  * `test_normality` implements the Jarque-Bera test for normality of residuals
  * `test_heteroskedasticity` implements a test for homoskedasticity of
    residuals similar to the Goldfeld-Quandt test
  * `test_serial_correlation` implements the Ljung-Box (or Box-Pierce) test for
    serial correlation of residuals
  + Unobserved Components
  * The class of univariate Unobserved Components models (also known as structural
    time series models) are now available (introduced in #2432). This includes as
    special cases the local level model and local linear trend model. Generically
    it allows decomposing a time series into trend, cycle, seasonal, and
    irregular components, optionally with exogenous regressors and / or
    autoregressive errors.
  + Multivariate Models
  * Two standard multivariate econometric models - vector autoregressive
    moving-average model with exogenous regressors (VARMAX) and Dynamic Factors
    models - are now available (introduced in #2563). The first is a popular
    reduced form method of exploring the covariance in several time series, and the
    second is a popular reduced form method of extracting a small number of common
    factors from a large dataset of observed series.
  + Recursive least squares
  * A model for recursive least squares, also known as expanding-window OLS, is
    now available in `statsmodels.regression` (introduced in #2830).
  + Other improvements to the state space framework include:
  * Improved missing data handling #2770, #2809
  * Ongoing refactoring and bug fixes in fringes and corner cases
  + New functionality in statistics
  * Contingency Tables #2418 (Kerby Shedden)
  * Local FDR, multiple testing #2297 (Kerby Shedden)
  * Mediation Analysis #2352 (Kerby Shedden)
  * weighted quantiles in DescrStatsW #2707 (Kerby Shedden)
  + Duration
  * Kaplan Meier Survival Function #2614 (Kerby Shedden)
  * Cumulative incidence rate function #3016 (Kerby Shedden)
  * frequency weights in Kaplan-Meier #2992 (Kerby Shedden)
  + Imputation
  * new subpackage in `statsmodels.imputation`
  * MICE #2076  (Frank Cheng GSOC 2014 and Kerby Shedden)
  * Imputation by regression on Order Statistic  #3019 (Paul Hobson)
  + Time Series Analysis
  * Markov Switching Models
    Markov switching dynamic regression and autoregression models are now
    available (introduced in #2980 by Chad Fulton). These models allow regression
    effects and / or autoregressive dynamics to differ depending on an unobserved
    "regime"; in Markov switching models, the regimes are assumed to transition
    according to a Markov process.
  + Statistics
  * KPSS stationarity, unit root test #2775 (N-Wouda)
  * The Brock Dechert Scheinkman (BDS) test for nonlinear dependence is now
    available (introduced in #934 by Chad Fulton)
  + Penalized Estimation
  * Elastic net: fit_regularized with L1/L2 penalization has been added to
    OLS, GLM and PHReg (Kerby Shedden)
  + GLM
  * Tweedie is now available as new family #2872 (Peter Quackenbush, Josef Perktold)
  * frequency weights for GLM (currently without full support) #
  * more flexible convergence options #2803 (Peter Quackenbush)
  + Multivariate
  * new subpackage that currently contains PCA
  * PCA was added in 0.7 to statsmodels.tools and is now in statsmodels.multivariate
  + Documentation
  * New doc build with latest jupyter and Python 3 compatibility (Tom Augspurger)
  + several existing functions have received improvements
  * seasonal_decompose: improved periodicity handling #2987 (ssktotoro ?)
  * tools add_constant, add_trend: refactoring and pandas compatibility #2240 (Kevin Sheppard)
  * acf, pacf, acovf: option for missing handling #3020 (joesnacks ?)
  * acf, pacf plots: allow array of lags #2989 (Kevin Sheppard)
  * io SimpleTable (summary): allow names with special characters #3015 (tvanessa ?)
  * tsa tools lagmat, lagmat2ds: pandas support #2310 #3042 (Kevin Sheppard)
  * CompareMeans: from_data, summary methods #2754 (Valery Tyumen)
  + Major Bugs fixed
  * see github issues
  + Backwards incompatible changes and deprecations
  * predict now returns a pandas Series if the exog argument is a DataFrame
  * PCA moved to multivariate compared to 0.7
- Update to Release 0.7.0 (never officially released)
  + Principal Component Analysis
  * Options to control the standardization (demeaning/studentizing)
  * Scree plotting
  * Information criteria for selecting the number of factors
  * R-squared plots to assess component fit
  * NIPALS implementation when only a small number of components are required
    and the dataset is large
  * Missing-value filling using the EM algorithm
  + Regression graphics for GLM/GEE
  * Added variable plots, partial residual plots, and CERES residual plots
    are available for GLM and GEE models by calling the methods
    `plot_added_variable`, `plot_partial_residuals`, and
    `plot_ceres_residuals` that are attached to the results classes.
  + State Space Models
  * State space methods provide a flexible structure for the estimation and
    analysis of a wide class of time series models. The Statsmodels implementation
    allows specification of state models, fast Kalman filtering, and built-in
    methods to facilitate maximum likelihood estimation of arbitrary models. One of
    the primary goals of this module is to allow end users to create and estimate
    their own models. Below is a short example demonstrating the ease with which a
    local level model can be specified and estimated:
  + Time Series Models (ARIMA) with Seasonal Effects
  * Additive and multiplicative seasonal effects
  * Flexible trend specications
  * Regression with SARIMA errors
  * Regression with time-varying coefficients
  * Measurement error in the endogenous variables
  + Generalized Estimating Equations GEE
  * EquivalenceClass covariance structure allows covariances to be specified by
    arbitrary collections of equality constraints #2188
  * add weights #2090
  * refactored margins #2158
  + MixedLM
  * added variance components support for MixedLM allowing a wider range of
    random effects structures to be specified
  * performance improvements from use of sparse matrices internally for
    random effects design matrices.
  + Other important new features
  * GLM: add scipy-based gradient optimization to fit #1961 (Kerby Shedden)
  * wald_test_terms: new method of LikelihoodModels to compute wald tests (F or chi-square)
    for terms or sets of coefficients #2132  (Josef Perktold)
  * add cov_type with fixed scale in WLS to allow chi2-fitting #2137 #2143
    (Josef Perktold, Christoph Deil)
  * VAR: allow generalized IRF and FEVD computation #2067 (Josef Perktold)
  * get_prediction new method for full prediction results (new API convention)
  + Major Bugs fixed
  * see github issues for a full list
  * bug in ARMA/ARIMA predict with `exog` #2470
  * bugs in VAR
  * x13: python 3 compatibility
- update to version 0.6.1:
  * PR #2111: Mixed profile
  * PR #2053: Add NominalGEE and OrdinalGEE to api
  * PR #2105: BUG: Avoid returning nans in lowess.
  * PR #2066: fixes #2065 (missing np)
  * PR #2089: BUG: Fix pos. def check in logdet
  * PR #2097: BUG: Make sure RE names are properly handled in MixedLM.
  * PR #2093: Add user control over what happens if a constant is already present.
  * PR #2084: BUG: Correct issue if patsy handles missing. Closes #2083.
  * #2102: MixedLM profile likelihood issue
  * #1798: lowess silently returns nans
  * #2065: In tukey_hsd.plot_simultaneous - “ones” not defined.
  * #2087: slogdet positive-definite check is wrong
  * #2099: Error in accessing mixedlm results with random slopes
  * #2043: ValueError on tsa with constant column
  * #2083: BUG: rlm errors on missing values
* Thu Nov  6 2014 toddrme2178@gmail.com
- Updated to version 0.6.0. Highlights:
  * Generalized Estimating Equation models
  * Linear Mixed Effects Models
  * Wrapper code for using X-12-ARIMA/X13-ARIMA-SEATS
  * Substantial optimization in the ARIMA estimation code
  * Some seasonal time-series features for plotting and decomposition
  * Many other feature enhancments and bug fixes
* Tue Oct 22 2013 toddrme2178@gmail.com
- Update to 0.5.0
  * No changelog available
- Add additional dependencies
* Wed Feb 13 2013 saschpe@suse.de
- Correctly fix non-executable script warnings (bnc#803223)
* Thu Jun 21 2012 scorot@free.fr
- version 0.4.1
  * add lowess and other functions to api and documentation
  * rename lowess module (old import path will be removed at next
  release)
  * new robust sandwich covariance estimators, moved out of sandbox
  * compatibility with pandas 0.8
  * new plots in statsmodels.graphics
  - ABLine plot
  - interaction plot
  * several bug fixes
  - see CHANGES.TXT for details
* Wed Jun 13 2012 scorot@free.fr
- use proper commands instead of deprecated macro
- remove unneeded -01 and --skip-build flags from the install
  command line
- set install prefix with %%%%{_prefix} instead of hard coded path
* Tue Jun 12 2012 scorot@free.fr
- first package
